@@ -1,8 +1,9 @@
 #' Generate resamples, permutations, or simulations based on
-#' `specify` and `hypothesize` inputs
+#' `specify` and (if needed) `hypothesize` inputs
 #' @param x a data frame that can be coerced into a \code{\link[dplyr]{tbl_df}}
 #' @param reps the number of resamples to generate
-#' @param type currently either \code{bootstrap}, \code{permute}, or \code{simulate}
+#' @param type currently either \code{bootstrap}, \code{permute}, 
+#' or \code{simulate}
 #' @param ... currently ignored
 #' @return A tibble containing \code{rep} generated datasets, indicated by the
 #' \code{replicate} column.
@@ -18,6 +19,8 @@
 
 generate <- function(x, reps = 1, type = "bootstrap", ...) {
 
+  attr(x, "generate") <- TRUE
+  
   if (type == "permute" &&
       any(is.null(attr(x, "response")), is.null(attr(x, "explanatory")))) {
     stop(paste("Please `specify()` an explanatory and a response variable",
@@ -29,8 +32,9 @@ generate <- function(x, reps = 1, type = "bootstrap", ...) {
     stop("Simulation requires a `point` null hypothesis on proportions.")
   }
   if (type == "bootstrap" &&
-      !(attr(attr(x, "params"), "names") %in% c("mu", "med", "sigma")) &&
-      !is.null(attr(x, "null"))) {
+        !(attr(attr(x, "params"), "names") %in% c("mu", "med", "sigma")) &&
+        !is.null(attr(x, "null"))
+      ) {
     stop(paste("Bootstrapping is inappropriate in this setting.",
           "Consider using `type = permute` or `type = simulate`."))
   }
@@ -55,23 +59,40 @@ bootstrap <- function(x, reps = 1, ...) {
     # If so, shift the variable chosen to have a mean corresponding
     # to that specified in `hypothesize`
     if(attr(attr(x, "params"), "names") == "mu"){
+      
       col <- as.character(attr(x, "response"))
-      x[[col]] <- x[[col]] - mean(x[[col]], na.rm = TRUE) + attr(x, "params")
+#      if(attr(x, "theory_type") != "One sample t"){
+        x[[col]] <- x[[col]] - mean(x[[col]], na.rm = TRUE) + attr(x, "params")
+#      }
+    
+      # Standardize after centering above
+      #####
+      # Determining whether or not to implement this t transformation
+      #####
+#      else {
+#        std_error <- stats::sd(x[[col]], na.rm = TRUE) / 
+#                        sqrt(length(x[[col]]))
+#        x[[col]] <- ( x[[col]] - mean(x[[col]], na.rm = TRUE) ) / std_error
+#      }
     }
 
     # Similarly for median
-    if(attr(attr(x, "params"), "names") == "med"){
+    else if(attr(attr(x, "params"), "names") == "med"){
       col <- as.character(attr(x, "response"))
-      x[[col]] <- x[[col]] - 
+      x[[col]] <- x[[col]] -
         stats::median(x[[col]], na.rm = TRUE) + attr(x, "params")
     }
 
+    # Implement confidence interval for bootstrapped proportions?
+    # Implement z transformation?
+
     # Similarly for sd
-    if(attr(attr(x, "params"), "names") == "sigma"){
-      col <- as.character(attr(x, "response"))
-      x[[col]] <- x[[col]] - 
-        stats::sd(x[[col]], na.rm = TRUE) + attr(x, "params")
-    }
+    ## Temporarily removed since this implementation does not scale correctly
+    # else if(attr(attr(x, "params"), "names") == "sigma"){
+    #   col <- as.character(attr(x, "response"))
+    #   x[[col]] <- x[[col]] -
+    #     stats::sd(x[[col]], na.rm = TRUE) + attr(x, "params")
+    # }
   }
 
   # Set variables for use in calculate()
@@ -79,7 +100,15 @@ bootstrap <- function(x, reps = 1, ...) {
   attr(result, "response") <- attr(x, "response")
   attr(result, "success") <- attr(x, "success")
   attr(result, "explanatory") <- attr(x, "explanatory")
-
+  attr(result, "response_type") <- attr(x, "response_type")
+  attr(result, "explanatory_type") <- attr(x, "explanatory_type")
+  attr(result, "distr_param") <- attr(x, "distr_param")
+  attr(result, "distr_param2") <- attr(x, "distr_param2")
+  attr(result, "theory_type") <- attr(x, "theory_type")
+  attr(result, "generate") <- attr(x, "generate")
+  
+  class(result) <- append("infer", class(result))
+  
   return(result)
 }
 
@@ -90,10 +119,24 @@ permute <- function(x, reps = 1, ...) {
     dplyr::bind_rows() %>%
     dplyr::mutate(replicate = rep(1:reps, each = nrow(x))) %>%
     dplyr::group_by(replicate)
+  
   attr(df_out, "null") <- attr(x, "null")
   attr(df_out, "response") <- attr(x, "response")
   attr(df_out, "success") <- attr(x, "success")
   attr(df_out, "explanatory") <- attr(x, "explanatory")
+  attr(df_out, "response_type") <- attr(x, "response_type")
+  attr(df_out, "explanatory_type") <- attr(x, "explanatory_type")
+  attr(df_out, "distr_param") <- attr(x, "distr_param")
+  attr(df_out, "distr_param2") <- attr(x, "distr_param2")
+  attr(df_out, "theory_type") <- attr(x, "theory_type")
+  attr(df_out, "generate") <- attr(x, "generate")
+  
+  class(df_out) <- append("infer", class(df_out))
+  
+  # Copy over all attr except for row names
+  # attributes(df_out)[which(names(attributes(df_out)) == "row.names")] <-
+  #   attributes(x)[which(names(attributes(x)) == "row.names")]
+  
   return(df_out)
 }
 
@@ -131,6 +174,26 @@ simulate <- function(x, reps = 1, ...) {
   attr(rep_tbl, "response") <- attr(x, "response")
   attr(rep_tbl, "success") <- attr(x, "success")
   attr(rep_tbl, "explanatory") <- attr(x, "explanatory")
+  attr(rep_tbl, "response_type") <- attr(x, "response_type")
+  attr(rep_tbl, "explanatory_type") <- attr(x, "explanatory_type")
+  attr(rep_tbl, "distr_param") <- attr(x, "distr_param")
+  attr(rep_tbl, "distr_param2") <- attr(x, "distr_param2")
+  attr(rep_tbl, "theory_type") <- attr(x, "theory_type")
+  attr(rep_tbl, "generate") <- attr(x, "generate")
+  
+  class(rep_tbl) <- append("infer", class(rep_tbl))
+  
+  # Copy over all attr except for row names
+  #attributes(rep_tbl)[which(names(attributes(rep_tbl)) == "row.names")] <-
+  #  attributes(x)[which(names(attributes(x)) == "row.names")]
+  
+  
+  # TODO: we may want to clean up this object before sending it out - do we
+  # really need all of the attributes() that it spits out?
+  
+  ## From Chester: Upon further inspection, I think we'll need a bunch of 
+  ## these to appropriately determine the theoretical distributions
+  ## when they exist
 
   return(dplyr::group_by(rep_tbl, replicate))
 }
