@@ -14,4 +14,8 @@ NULL
 ## quiets concerns of R CMD check re: the .'s that appear in pipelines
 ## From Jenny Bryan's googlesheets package
 if(getRversion() >= "2.15.1")  
-  utils::globalVariables(c("prop", "stat", "xbar", "xtilde", "statistic", "."))
+  utils::globalVariables(c("prop", "stat", "xbar", "xtilde", "x", "..density..",
+                           "statistic", ".", "parameter", "p.value",
+                           "xmin", "xmax", "density", "denom",
+                           "diff_prop", "group_num", "n1", "n2",
+                           "num_suc", "p_hat", "total_suc", "explan", "probs"))
