@@ -30,7 +30,7 @@ test_that("variable chosen is of appropriate class (one var problems)", {
   gen_iris1 <- iris %>%
     specify(Species ~ NULL) %>%
     hypothesize(null = "point",
-                p = c("setosa" = .5, 
+                p = c("setosa" = .5,
                       "versicolor" = .25, "virginica" = .25)) %>%
     generate(reps = 10, type = "simulate")
   expect_error(calculate(gen_iris1, stat = "mean"))
@@ -71,6 +71,8 @@ test_that("grouping (explanatory) variable is a factor (two var problems)", {
     generate(reps = 10, type = "permute")
   expect_error(calculate(gen_iris2, stat = "diff in means"))
   expect_error(calculate(gen_iris2, stat = "diff in medians"))
+  # Since shifts to "Slope with t"
+  expect_silent(calculate(gen_iris2, stat = "t"))
 })
 
 test_that("grouping (explanatory) variable is numeric (two var problems)", {
@@ -79,6 +81,8 @@ test_that("grouping (explanatory) variable is numeric (two var problems)", {
     hypothesize(null = "independence") %>%
     generate(reps = 10, type = "permute")
   expect_error(calculate(gen_iris2a, stat = "slope"))
+  # Since shifts to "Slope with t"
+  expect_error(calculate(gen_iris2a, stat = "t"))
   expect_error(calculate(gen_iris2a, stat = "diff in medians"))
 })
 
@@ -91,24 +95,29 @@ test_that("response variable is a factor (two var problems)", {
 
   # Species has more than 2 levels
   gen_iris4 <- iris %>%
-    dplyr::mutate(Sepal.Length.Group = 
+    dplyr::mutate(Sepal.Length.Group =
                     dplyr::if_else(Sepal.Length > 5, ">5", "<=5")) %>%
-    specify(Sepal.Length.Group ~ Species) %>%
+    specify(Sepal.Length.Group ~ Species, success = ">5") %>%
     hypothesize(null = "independence") %>%
     generate(reps = 10, type = "permute")
   expect_error(calculate(gen_iris4, stat = "diff in props"))
+
+  expect_error(calculate(gen_iris4, stat = "t"))
   
   # Check successful diff in props
   gen_iris4a <- iris %>%
-    dplyr::mutate(Sepal.Length.Group = 
+    dplyr::mutate(Sepal.Length.Group =
                     dplyr::if_else(Sepal.Length > 5, ">5", "<=5")) %>%
-    dplyr::mutate(Sepal.Width.Group = 
-                    dplyr::if_else(Sepal.Width > 3, "large", "small")) %>% 
+    dplyr::mutate(Sepal.Width.Group =
+                    dplyr::if_else(Sepal.Width > 3, "large", "small")) %>%
     specify(Sepal.Length.Group ~ Sepal.Width.Group, success = ">5") %>%
     hypothesize(null = "independence") %>%
     generate(reps = 10, type = "permute")
   expect_silent(calculate(gen_iris4a, stat = "diff in props",
                           order = c("large", "small")))
+  expect_silent(calculate(gen_iris4a, stat = "z",
+                          order = c("large", "small")))
+  expect_error(calculate(gen_iris4a, stat = "z"))
 })
 
 gen_iris5 <- iris %>%
@@ -119,6 +128,21 @@ test_that("response variable is numeric (two var problems)", {
   expect_error(calculate(gen_iris5, stat = "F"))
 })
 
+test_that("two sample mean-type problems are working", {
+  gen_iris5a <- iris %>%
+    dplyr::mutate(Sepal.Length.Group =
+                    dplyr::if_else(Sepal.Length > 5, ">5", "<=5")) %>% 
+    specify(Sepal.Width ~ Sepal.Length.Group) %>% 
+    hypothesize(null = "independence") %>% 
+    generate(reps = 10, type = "permute")
+  expect_error(calculate(gen_iris5a, stat = "diff in means"))
+  expect_silent(calculate(gen_iris5a, stat = "diff in means",
+                          order = c(">5", "<=5")))
+  expect_error(calculate(gen_iris5a, stat = "t"))
+  expect_silent(calculate(gen_iris5a, stat = "t",
+                          order = c(">5", "<=5")))
+})
+
 test_that("properties of tibble passed-in are correct", {
   expect_is(gen_iris5, "grouped_df")
   expect_equal(ncol(gen_iris5), 3)
@@ -128,47 +152,44 @@ test_that("properties of tibble passed-in are correct", {
     generate(reps = 10, type = "bootstrap")
   expect_equal(ncol(gen_iris6), 2)
   expect_error(calculate(gen_iris6))
-
-  # infer class is removed currently after `generate()`
-  expect_false("infer" %in% class(gen_iris6))
 })
 
-test_that("success is working for diff in means", {
+test_that("order is working for diff in means", {
   gen_iris7 <- iris %>%
-    dplyr::mutate(Sepal.Length.Group = 
+    dplyr::mutate(Sepal.Length.Group =
                     dplyr::if_else(Sepal.Length > 5, ">5", "<=5")) %>%
     specify(Sepal.Width ~ Sepal.Length.Group) %>%
     hypothesize(null = "independence") %>%
     generate(reps = 10, type = "permute")
-  expect_equal(nrow(calculate(gen_iris7, stat = "diff in means", 
+  expect_equal(nrow(calculate(gen_iris7, stat = "diff in means",
                               order = c(">5", "<=5"))), 10)
-  expect_equal(ncol(calculate(gen_iris7, stat = "diff in means", 
+  expect_equal(ncol(calculate(gen_iris7, stat = "diff in means",
                               order = c(">5", "<=5"))), 2)
 })
 
 test_that("chi-square matches chisq.test value", {
   gen_iris8 <- iris %>%
-    dplyr::mutate(Petal.Length.Group = 
+    dplyr::mutate(Petal.Length.Group =
                     dplyr::if_else(Sepal.Length > 5, ">5", "<=5")) %>%
-    specify(Petal.Length.Group ~ Species) %>%
+    specify(Petal.Length.Group ~ Species, success = ">5") %>%
     hypothesize(null = "independence") %>%
     generate(reps = 10, type = "permute")
   infer_way <- calculate(gen_iris8, stat = "Chisq")
   #chisq.test way
   trad_way <- gen_iris8 %>%
     dplyr::group_by(replicate) %>%
-    dplyr::do(broom::tidy(stats::chisq.test(table(.$Petal.Length.Group, 
+    dplyr::do(broom::tidy(stats::chisq.test(table(.$Petal.Length.Group,
                                                   .$Species)))) %>%
     dplyr::select(replicate, stat = statistic) %>%
-    dplyr::ungroup() %>%
-    dplyr::mutate(replicate = as.factor(replicate))
+    dplyr::ungroup() #%>%
+ #   dplyr::mutate(replicate = as.factor(replicate))
   expect_equal(infer_way, trad_way)
 
   gen_iris9 <- iris %>%
     specify(Species ~ NULL) %>%
     hypothesize(null = "point",
-                p = c("setosa" = 1/3, 
-                      "versicolor" = 1/3, 
+                p = c("setosa" = 1/3,
+                      "versicolor" = 1/3,
                       "virginica" = 1/3)) %>%
     generate(reps = 10, type = "simulate")
   infer_way <- calculate(gen_iris9, stat = "Chisq")
@@ -178,34 +199,53 @@ test_that("chi-square matches chisq.test value", {
     dplyr::do(broom::tidy(stats::chisq.test(table(.$Species)))) %>%
     dplyr::select(replicate, stat = statistic)
   expect_equal(infer_way, trad_way)
+  
+  gen_iris9a <- iris %>%
+    specify(Species ~ NULL) %>%
+    hypothesize(null = "point",
+                p = c("setosa" = 0.8,
+                      "versicolor" = 0.1,
+                      "virginica" = 0.1)) %>%
+    generate(reps = 10, type = "simulate")
+  infer_way <- calculate(gen_iris9a, stat = "Chisq")
+  #chisq.test way
+  trad_way <- gen_iris9a %>%
+    dplyr::group_by(replicate) %>%
+    dplyr::do(broom::tidy(stats::chisq.test(table(.$Species),
+                                            p = c(0.8, 0.1, 0.1)))) %>%
+    dplyr::select(replicate, stat = statistic)
+  expect_equal(infer_way, trad_way)
+  
 })
 
 test_that("`order` is working", {
   gen_iris10 <- iris %>%
-    dplyr::mutate(Petal.Length.Group = 
+    dplyr::mutate(Petal.Length.Group =
                     dplyr::if_else(Sepal.Length > 5, ">5", "<=5")) %>%
     specify(Petal.Width ~ Petal.Length.Group) %>%
     hypothesize(null = "independence") %>%
     generate(reps = 10, type = "permute")
-  expect_error(calculate(gen_iris10, stat = "diff in means", 
+  expect_error(calculate(gen_iris10, stat = "diff in means",
                          order = c(TRUE, FALSE)))
 
   gen_iris11 <- iris %>%
-    dplyr::mutate(Petal.Length.Group = 
+    dplyr::mutate(Petal.Length.Group =
                     dplyr::if_else(Sepal.Length > 5, ">5", "<=5")) %>%
     specify(Petal.Width ~ Petal.Length.Group) %>%
     generate(reps = 10, type = "bootstrap")
-  expect_error(calculate(gen_iris11, stat = "diff in medians", 
+  expect_error(calculate(gen_iris11, stat = "diff in medians",
                          order = ">5"))
-  expect_error(calculate(gen_iris11, stat = "diff in medians", 
+  expect_error(calculate(gen_iris11, stat = "diff in medians",
                          order = c(NA, ">5")))
-  expect_error(calculate(gen_iris11, stat = "diff in medians", 
+  expect_error(calculate(gen_iris11, stat = "diff in medians",
                          order = c(">5", "<=4")))
-  expect_silent(calculate(gen_iris11, stat = "diff in medians", 
+  expect_silent(calculate(gen_iris11, stat = "diff in medians",
                          order = c(">5", "<=5")))
-  expect_error(calculate(gen_iris11, stat = "diff in means", 
+  expect_error(calculate(gen_iris11, stat = "diff in means",
                          order = c(">5", "<=4", ">4")))
+  # order not given
   expect_error(calculate(gen_iris11, stat = "diff in means"))
+  
 })
 
 test_that('success is working for stat = "prop"', {
@@ -217,14 +257,17 @@ test_that('success is working for stat = "prop"', {
     generate(reps = 10, type = "simulate")
   expect_silent(gen_iris12 %>%
                   calculate(stat = "prop"))
+  expect_silent(gen_iris12 %>%
+                  calculate(stat = "z"))
+  
 })
 
 test_that("NULL response gives error", {
   iris_improp <- tibble::as_tibble(iris) %>%
-    dplyr::select(Sepal.Width, Sepal.Length) 
-  
+    dplyr::select(Sepal.Width, Sepal.Length)
+
   expect_error(
-    iris_improp %>% calculate(stat = "mean") 
+    iris_improp %>% calculate(stat = "mean")
   )
 })
 
@@ -243,3 +286,28 @@ test_that("Permute slope test works", {
     generate(reps = 10, type = "permute")
   expect_silent(calculate(gen_iris14, stat = "slope"))
 })
+
+test_that("order being given when not needed gives warning", {
+  gen_iris15 <- iris %>%
+    dplyr::mutate(Petal.Length.Group =
+                    dplyr::if_else(Sepal.Length > 4, ">4", "<=4")) %>%
+    specify(Petal.Length.Group ~ Species, success = ">4") %>%
+    hypothesize(null = "independence") %>%
+    generate(reps = 10, type = "permute")
+  expect_warning(calculate(gen_iris15, stat = "Chisq",
+                           order = c("setosa", "virginica")))
+})
+
+## Breaks oldrel build. Commented out for now.
+# test_that("warning given if calculate without generate", {
+#   expect_warning(iris %>% 
+#                    specify(Species ~ NULL) %>% 
+#                    hypothesize(null = "point", 
+#                                p = c("setosa" = 0.4,
+#                                      "versicolor" = 0.4,
+#                                      "virginica" = 0.2)) %>% 
+#                    #generate(reps = 10, type = "simulate") %>% 
+#                    calculate(stat = "Chisq")
+#   )
+#   
+# })
